/* GDA Common Library
 * Copyright (C) 2000 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#if !defined(__gda_common_h__)
#  define __gda_common_h__

/*
 * This is the main header file for the libgda-common library
 */

#include <gda-corba.h>
#include <gda-log.h>
#include <gda-config.h>
#include <gda-thread.h>
#include <gda-xml-file.h>
#include <gda-xml-database.h>
#include <gda-xml-query.h>

void gda_init (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);

#endif
